@@ -5,7 +5,7 @@ use serde::{Deserialize, Serialize};
 
 pub use checkout_server_derive::Server;
 
-use crate::context::{Context, ContextProvider};
+use crate::context::{ClientContext, ClientContextProvider};
 use crate::customer::{Address, Contact};
 use crate::error::Error;
 use crate::money::Currency;
@@ -29,7 +29,7 @@ pub struct AddOrRemoveItemParams {
 }
 
 #[async_trait]
-pub trait Server<'a, T: Context>: ContextProvider<'a, T> {
+pub trait Server<'a, C: ClientContext>: ClientContextProvider<'a, C> {
     type Context: ServerContext;
     fn api_description() -> ApiDescription<Self::Context>;
     async fn start(self) -> Result<(), Error>;
